declare type KeyAttributes = {
    threshold?: number;
    maxRanking: number;
    minRanking: number;
};
interface RankingInfo {
    rankedValue: string;
    rank: number;
    keyIndex: number;
    keyThreshold: number | undefined;
}
interface ValueGetterKey<ItemType> {
    (item: ItemType): string;
}
interface IndexedItem<ItemType> {
    item: ItemType;
    index: number;
}
interface RankedItem<ItemType> extends RankingInfo, IndexedItem<ItemType> {
}
interface BaseSorter<ItemType> {
    (a: RankedItem<ItemType>, b: RankedItem<ItemType>): number;
}
interface KeyAttributesOptions<ItemType> {
    key?: string | ValueGetterKey<ItemType>;
    threshold?: number;
    maxRanking?: number;
    minRanking?: number;
}
declare type KeyOption<ItemType> = KeyAttributesOptions<ItemType> | ValueGetterKey<ItemType> | string;
interface MatchSorterOptions<ItemType = unknown> {
    keys?: Array<KeyOption<ItemType>>;
    threshold?: number;
    baseSort?: BaseSorter<ItemType>;
    keepDiacritics?: boolean;
}
declare const rankings: {
    CASE_SENSITIVE_EQUAL: number;
    EQUAL: number;
    STARTS_WITH: number;
    WORD_STARTS_WITH: number;
    CONTAINS: number;
    ACRONYM: number;
    MATCHES: number;
    NO_MATCH: number;
};
declare const defaultBaseSortFn: BaseSorter<unknown>;
/**
 * Takes an array of items and a value and returns a new array with the items that match the given value
 * @param {Array} items - the items to sort
 * @param {String} value - the value to use for ranking
 * @param {Object} options - Some options to configure the sorter
 * @return {Array} - the new sorted array
 */
declare function matchSorter<ItemType = string>(items: Array<ItemType>, value: string, options?: MatchSorterOptions<ItemType>): Array<ItemType>;
declare namespace matchSorter {
    var rankings: {
        CASE_SENSITIVE_EQUAL: number;
        EQUAL: number;
        STARTS_WITH: number;
        WORD_STARTS_WITH: number;
        CONTAINS: number;
        ACRONYM: number;
        MATCHES: number;
        NO_MATCH: number;
    };
}
export { matchSorter, rankings, defaultBaseSortFn };
export type { MatchSorterOptions, KeyAttributesOptions, KeyOption, KeyAttributes, RankingInfo, ValueGetterKey, };
